﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace TwainDemoCSharp
{
    public partial class fMain : Form
    {
        public fMain()
        {
            InitializeComponent();
        }

        private void chkUseInt_CheckedChanged(object sender, EventArgs e)
        {
            // This checkbox enables/disables the TWAIN user interface.
            // When the user interface is used, all controls in grpConfig are to be disabled

            grpConfig.Enabled = !chkUseInt.Checked;
        }

        private void cmdAcquire_Click(object sender, EventArgs e)
        {
            double resolution;
            double tlLeft, tlRight, tlTop, tlBottom;

            // Select the device shown in the combobox
            axImageBox1.CurrentTwainDevice = cboSelect.SelectedIndex;

            // Only continue if the device is connected
            if (axImageBox1.TwainConnected)
            {
                // Either use the interface, or set properties from the
                // various text boxes and the combo box
                if (chkUseInt.Checked)
                    axImageBox1.UseTwainInterface = true;
                else
                {
                    axImageBox1.TwainPixelType = (csXImageTrial.TxPixelType)cboPixType.SelectedIndex;
                    if (Double.TryParse(txtRes.Text, out resolution))
                        axImageBox1.TwainResolution = resolution;
                    if ((Double.TryParse(txtTop.Text, out tlTop)) && (Double.TryParse(txtLeft.Text, out tlLeft)) &&
                        (Double.TryParse(txtRight.Text, out tlRight)) && (Double.TryParse(txtBtm.Text, out tlBottom)))
                        axImageBox1.SetTwainLayout(tlLeft, tlRight, tlTop, tlBottom);
                    axImageBox1.UseTwainInterface = false;
                }
            }
            // Acquire the image
            axImageBox1.Acquire();
        }

        private void cmdGetCur_Click(object sender, EventArgs e)
        {
            // Select the TWAIN device, then retrieve the current property
            // values if it is connected
            axImageBox1.CurrentTwainDevice = cboSelect.SelectedIndex;
            if (axImageBox1.TwainConnected)
            {
                cboPixType.SelectedIndex = (int)axImageBox1.TwainPixelType;
                axImageBox1.TwainUnits = csXImageTrial.TxTwainUnits.unInches;
                txtRes.Text = axImageBox1.TwainResolution.ToString();
                txtTop.Text = axImageBox1.TwainTop.ToString();
                txtLeft.Text = axImageBox1.TwainLeft.ToString();
                txtRight.Text = axImageBox1.TwainRight.ToString();
                txtBtm.Text = axImageBox1.TwainBottom.ToString();
            }
        }

        private void cmdSave_Click(object sender, EventArgs e)
        {
            // Save to a file
            if (axImageBox1.ImageLoaded)
                axImageBox1.SaveToFile(txtFileName.Text + cboFileExt.Text);
        }

        private void fMain_Load(object sender, EventArgs e)
        {
            int n;

            // Initialise the contents of the various comboboxes
            n = axImageBox1.TwainDeviceCount;
            cboSelect.Items.Clear();
            for (int i = 1; i <= n; i++)
                cboSelect.Items.Add(axImageBox1.get_TwainDeviceName(i - 1));
            cboSelect.SelectedIndex = 0;

            cboPixType.Items.Clear();
            cboPixType.Items.Add("Black/White");
            cboPixType.Items.Add("Greyscale");
            cboPixType.Items.Add("RGB Colour");
            cboPixType.SelectedIndex = 2;

            cboFileExt.Items.Clear();
            cboFileExt.Items.Add(".bmp");
            cboFileExt.Items.Add(".gif");
            cboFileExt.Items.Add(".jpg");
            cboFileExt.Items.Add(".pcx");
            cboFileExt.Items.Add(".png");
            cboFileExt.Items.Add("psd");
            cboFileExt.Items.Add(".pdf");
            cboFileExt.SelectedIndex = 0;

        }
    }
}
